Class: Yorishiro::Skill
- Inherits:
-
Object
- Object
- Yorishiro::Skill
- Defined in:
- lib/yorishiro/skill.rb
Defined Under Namespace
Classes: Prompt
Instance Method Summary collapse
- #description ⇒ Object
- #execute(_context) ⇒ Object
- #name ⇒ Object
-
#prompt(text) ⇒ Object
Convenience for subclasses:
prompt("...")inside #execute returns a Prompt so the returned text is sent to the LLM.
Instance Method Details
#description ⇒ Object
20 21 22 |
# File 'lib/yorishiro/skill.rb', line 20 def description raise SkillNotImplementedError, "#{self.class}#description is not implemented" end |
#execute(_context) ⇒ Object
24 25 26 |
# File 'lib/yorishiro/skill.rb', line 24 def execute(_context) raise SkillNotImplementedError, "#{self.class}#execute is not implemented" end |
#name ⇒ Object
16 17 18 |
# File 'lib/yorishiro/skill.rb', line 16 def name raise SkillNotImplementedError, "#{self.class}#name is not implemented" end |
#prompt(text) ⇒ Object
Convenience for subclasses: prompt("...") inside #execute returns a
Prompt so the returned text is sent to the LLM.
12 13 14 |
# File 'lib/yorishiro/skill.rb', line 12 def prompt(text) Prompt.new(text) end |